@@ -2,8 +2,10 @@
 
 set -e
 
+user=`whoami`
+
 sudo vmdebootstrap \
- --owner $(whoami) --verbose \
+ --owner ${user} --verbose \
  --mirror http://http.debian.net/debian \
  --log beaglebone-black.log --log-level debug \
  --arch armhf \
@@ -11,11 +13,10 @@ sudo vmdebootstrap \
  --enable-dhcp \
  --configure-apt \
  --no-extlinux \
- --no-kernel \
  --package u-boot \
- --package linux-image-armmp \
+ --package dosfstools \
  --distribution sid \
  --serial-console-command "'/sbin/getty -L ttyO0 115200 vt100'" \
  --customize "beagleboneblack-customise.sh" \
- --bootsize 50m --boottype vfat \
+ --bootsize 100mib --boottype vfat \
  "$@"
