@@ -2,8 +2,10 @@
 
 set -e
 
+user=`whoami`
+
 sudo vmdebootstrap \
- --owner $(whoami) --verbose \
+ --owner ${user} --verbose \
  --size 3G \
  --mirror http://http.debian.net/debian \
  --log cubietruck.log --log-level debug \
@@ -11,13 +13,7 @@ sudo vmdebootstrap \
  --foreign /usr/bin/qemu-arm-static \
  --enable-dhcp \
  --configure-apt \
- --no-extlinux \
- --no-kernel \
- --package u-boot \
- --package linux-image-armmp \
  --distribution sid \
  --serial-console-command "/sbin/getty -L ttyS0 115200 vt100" \
  --customize "cubietruck-customise.sh" \
- --serial-console-command \
- --bootsize 50m --boottype vfat \
  "$@"
